@@ -50,7 +50,10 @@ class Maze(DOMWidget):
         self.model.js_call_counter +=1
 
         if self.model.has_balance():
-            self.current_call = json.dumps({'method_name': method_name, 'params': params, 'cb': cb})
+            bot = self.bot()
+            stats = bot.stats.report() if bot is not None else {}
+
+            self.current_call = json.dumps({'method_name': method_name, 'params': params, 'cb': cb, 'stats': stats})
         else:
             self.current_call = json.dumps({'method_name': 'halt', 'params': [], 'cb': cb})
             raise RuntimeError("Instruction Quota Exceeded")
