@@ -5,6 +5,20 @@ dir_names = ["east", "north","west", "south"]
 from .models.world_model import print_success, print_error
 import time as _time
 
+
+class Stats():
+    def __init__(self, bot):
+        self.bot = bot
+    
+    def report(self):
+        return {
+            'max_capacity': self.bot.max_capacity,
+            'current_load': len(self.bot.last_picked),
+            'total_moves': self.bot.move_count,
+            'basket': self.bot.basket()
+        }
+
+
 class Robot():
     def __init__(self, index, robot_model, world):
         self.model = robot_model
@@ -15,6 +29,9 @@ class Robot():
         self.speed  = 0.5
         self.last_picked = []
         self.count_report = None
+        self.max_capacity = None
+        self.move_count = 0
+        self.stats = Stats(self)
  
     @property
     def x(self):
@@ -68,6 +85,7 @@ class Robot():
             xx, yy = _directions[self.dir]
             self.x += xx
             self.y += yy
+            self.move_count += 1
         else:
             print_error("Opps You Hit the walls") 
             self.world.js_call('error', ['Opps You Hit the wall'])
@@ -389,6 +407,9 @@ class Robot():
         --------
         >>> bot.take()
         """
+        if self.max_capacity is not None and self.max_capacity > len(self.last_picked):
+            raise RuntimeError(f"Can't Carry more than {self.max_capacity} items")
+
         self.world_model.incr_instruction()
         cell = self.cell()
         if not cell.editable["pick"]:
